@@ -8,11 +8,10 @@ import traceback
 import uuid
 from enum import Enum
 
+from bec_lib import Alarms, MessageEndpoints, bec_logger, messages, threadlocked
 from rich.console import Console
 from rich.table import Table
 
-from bec_lib import Alarms, MessageEndpoints, bec_logger, messages, threadlocked
-
 from .errors import LimitError, ScanAbortion
 from .scan_assembler import ScanAssembler
 from .scans import ScanBase
@@ -80,7 +79,7 @@ class QueueManager:
             self.connector.raise_alarm(
                 severity=Alarms.MAJOR,
                 source=msg.content,
-                content=content,
+                msg=content,
                 alarm_type=exc.__class__.__name__,
                 metadata=msg.metadata,
             )
@@ -94,9 +93,7 @@ class QueueManager:
 
     def _start_scan_queue_consumer(self) -> None:
         self._scan_queue_consumer = self.connector.consumer(
-            MessageEndpoints.scan_queue_insert(),
-            cb=self._scan_queue_callback,
-            parent=self,
+            MessageEndpoints.scan_queue_insert(), cb=self._scan_queue_callback, parent=self
         )
         self._scan_queue_modification_consumer = self.connector.consumer(
             MessageEndpoints.scan_queue_modification(),
@@ -108,7 +105,7 @@ class QueueManager:
 
     @staticmethod
     def _scan_queue_callback(msg, parent, **_kwargs) -> None:
-        scan_msg = messages.ScanQueueMessage.loads(msg.value)
+        scan_msg = msg.value
         logger.info(f"Receiving scan: {scan_msg.content}")
         # instructions = parent.scan_assembler.assemble_device_instructions(scan_msg)
         queue = scan_msg.content.get("queue", "primary")
@@ -117,7 +114,7 @@ class QueueManager:
 
     @staticmethod
     def _scan_queue_modification_callback(msg, parent, **_kwargs):
-        scan_mod_msg = messages.ScanQueueModificationMessage.loads(msg.value)
+        scan_mod_msg = msg.value
         logger.info(f"Receiving scan modification: {scan_mod_msg.content}")
         if scan_mod_msg:
             parent.scan_interception(scan_mod_msg)
@@ -238,7 +235,7 @@ class QueueManager:
             logger.info(f"\n {queue}")
         self.producer.set_and_publish(
             MessageEndpoints.scan_queue_status(),
-            messages.ScanQueueStatusMessage(queue=queue_export).dumps(),
+            messages.ScanQueueStatusMessage(queue=queue_export),
         )
 
     def describe_queue(self) -> list:
@@ -539,7 +536,7 @@ class RequestBlock:
     def describe(self):
         """prepare a dictionary that summarizes the request block"""
         return {
-            "msg": self.msg.dumps(),
+            "msg": self.msg,
             "RID": self.RID,
             "scan_motors": self.scan_motors,
             "readout_priority": self.readout_priority,
@@ -622,6 +619,8 @@ class RequestBlockQueue:
     def increase_scan_number(self) -> None:
         """increase the scan number counter"""
         rbl = self.active_rb
+        if rbl is None:
+            return
         if not rbl.is_scan and rbl.scan_def_id is None:
             return
         if rbl.scan_def_id is None or rbl.msg.content["scan_type"] == "close_scan_def":
@@ -650,7 +649,7 @@ class RequestBlockQueue:
             self.scan_queue.queue_manager.connector.raise_alarm(
                 severity=Alarms.MAJOR,
                 source=self.active_rb.msg.content,
-                content=limit_error.args[0],
+                msg=limit_error.args[0],
                 alarm_type=limit_error.__class__.__name__,
                 metadata={},
             )
@@ -662,7 +661,7 @@ class RequestBlockQueue:
             self.scan_queue.queue_manager.connector.raise_alarm(
                 severity=Alarms.MAJOR,
                 source=self.active_rb.msg.content,
-                content=content,
+                msg=content,
                 alarm_type=exc.__class__.__name__,
                 metadata={},
             )
@@ -745,6 +744,7 @@ class InstructionQueueItem:
     def abort(self) -> None:
         """abort and clear all the instructions from the instruction queue"""
         self.instructions = iter([])
+        # self.queue.request_blocks_queue.clear()
 
     def append_scan_request(self, msg):
         """append a scan message to the instruction queue"""
@@ -779,9 +779,9 @@ class InstructionQueueItem:
             "request_blocks": request_blocks,
             "scan_number": self.scan_number,
             "status": self.status.name,
-            "active_request_block": self.active_request_block.describe()
-            if self.active_request_block
-            else None,
+            "active_request_block": (
+                self.active_request_block.describe() if self.active_request_block else None
+            ),
         }
         return content
 
@@ -791,7 +791,7 @@ class InstructionQueueItem:
             status=self.status.name, queueID=self.queue_id, info=self.describe()
         )
         self.parent.queue_manager.producer.lpush(
-            MessageEndpoints.scan_queue_history(), msg.dumps(), max_size=100
+            MessageEndpoints.scan_queue_history(), msg, max_size=100
         )
 
     def __iter__(self):
@@ -826,14 +826,16 @@ class InstructionQueueItem:
         except StopIteration:
             if not self.scan_macros_complete:
                 logger.info(
-                    f"Waiting for new instructions or scan macro to be closed (scan def ids: {self.queue.scan_def_ids})"
+                    "Waiting for new instructions or scan macro to be closed (scan def ids:"
+                    f" {self.queue.scan_def_ids})"
                 )
                 time.sleep(0.1)
             elif self.queue_group is not None and not self.queue_group_is_closed:
                 self.queue.active_rb = None
                 self.parent.queue_manager.send_queue_status()
                 logger.info(
-                    f"Waiting for new instructions or queue group to be closed (group id: {self.queue_group})"
+                    "Waiting for new instructions or queue group to be closed (group id:"
+                    f" {self.queue_group})"
                 )
                 time.sleep(0.1)
             else:
